#
# spec file for package knewstuff
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5NewStuff5
%define _tar_path 5.71
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           knewstuff
Version:        5.71.0
Release:        lp152.2.3.1
Summary:        Framework for downloading and sharing additional application data
License:        LGPL-2.1-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM
Patch1:         0001-Include-a-user-agent-on-KNS-requests.patch
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(KF5Archive) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Attica) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Completion) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Config) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5IconThemes) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5ItemViews) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Package) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Service) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5TextWidgets) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5WidgetsAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5XmlGui) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(Qt5Core) >= 5.12.0
BuildRequires:  cmake(Qt5Qml) >= 5.12.0
BuildRequires:  cmake(Qt5Quick) >= 5.12.0
BuildRequires:  cmake(Qt5Widgets) >= 5.12.0
BuildRequires:  cmake(Qt5Xml) >= 5.12.0

%description
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification.

%package -n %{lname}
Summary:        Framework for downloading and sharing additional application data
Group:          System/GUI/KDE
Requires:       %{name}
Obsoletes:      libKF5NewStuff4
%if %{with lang}
Recommends:     %{lname}-lang = %{version}
%endif

%description -n %{lname}
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification.

%package -n libKF5NewStuffCore5
Summary:        Framework for downloading and sharing additional application data
Group:          System/GUI/KDE

%description -n libKF5NewStuffCore5
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification.

%package imports
Summary:        Framework for downloading and sharing additional application data
Group:          System/GUI/KDE

%description imports
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification.

%package core-devel
Summary:        Framework for downloading and sharing additional application data
Group:          Development/Libraries/KDE
Requires:       extra-cmake-modules
Requires:       libKF5NewStuffCore5 = %{version}
Requires:       cmake(KF5Attica) >= %{_kf5_bugfix_version}

%description core-devel
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification. Development files.

%package quick-devel
Summary:        Framework for downloading and sharing additional application data
Group:          Development/Libraries/KDE
Requires:       %{name}-core-devel = %{version}
Requires:       %{name}-imports = %{version}
Requires:       extra-cmake-modules

%description quick-devel
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification. Development files.

%package devel
Summary:        Framework for downloading and sharing additional application data
Group:          Development/Libraries/KDE
Requires:       %{lname} = %{version}
Requires:       %{name}-core-devel = %{version}
Requires:       extra-cmake-modules
Requires:       libKF5NewStuffCore5 = %{version}
Requires:       cmake(KF5Service) >= %{_kf5_bugfix_version}
Requires:       cmake(KF5XmlGui) >= %{_kf5_bugfix_version}
Requires:       cmake(Qt5Widgets) >= 5.12.0

%description devel
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification. Development files.

%lang_package -n %{lname}

%prep
%autosetup -p1

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %fdupes %{buildroot}

%if %{with lang}
%find_lang %{name}5
%endif

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig
%post -n libKF5NewStuffCore5 -p /sbin/ldconfig
%postun -n libKF5NewStuffCore5 -p /sbin/ldconfig

%if %{with lang}
%files -n %{lname}-lang -f %{name}5.lang
%endif

%files
%license COPYING*
%doc README*
%{_kf5_datadir}/kmoretools/
%{_kf5_debugdir}/knewstuff.categories

%files -n %{lname}
%license COPYING*
%doc README*
%{_kf5_libdir}/libKF5NewStuff.so.*

%files -n libKF5NewStuffCore5
%license COPYING*
%doc README*
%{_kf5_libdir}/libKF5NewStuffCore.so.*

%files imports
%license COPYING*
%doc README*
%{_kf5_qmldir}/

%files core-devel
%license COPYING*
%doc README*
%{_kf5_libdir}/libKF5NewStuffCore.so
%{_kf5_libdir}/cmake/KF5NewStuffCore/
%{_kf5_includedir}/knewstuffcore_version.h
%dir %{_kf5_includedir}/KNewStuff3
%{_kf5_includedir}/KNewStuff3/KNSCore/
%{_kf5_includedir}/KNewStuff3/knscore/
%{_kf5_mkspecsdir}/qt_KNewStuffCore.pri

%files quick-devel
%license COPYING*
%doc README*
%{_kf5_libdir}/cmake/KF5NewStuffQuick/
%{_kf5_includedir}/knewstuffquick_version.h

%files devel
%license COPYING*
%doc README*
%{_kf5_libdir}/libKF5NewStuff.so
%{_kf5_libdir}/cmake/KF5NewStuff/
%dir %{_kf5_includedir}/KNewStuff3
%{_kf5_includedir}/KNewStuff3/KNS3/
%{_kf5_includedir}/KNewStuff3/kns3/
%{_kf5_includedir}/knewstuff_version.h
%{_kf5_mkspecsdir}/qt_KNewStuff.pri

%changelog
* Sat Oct  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to help alleviate server traffic issues (boo#1191512):
  * 0001-Include-a-user-agent-on-KNS-requests.patch
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Don't duplicate error messages in a passive notification (kde#421425)
  * Port from runUrl to OpenUrlJob
  * Fix incorrect colours in the KNS Quick messagebox (kde#421270)
  * Do not mark entry as uninstalled if uninstallation script failed (kde#420312)
  * KNS: Deprecate isRemote method and handle parse error properly
  * KNS: Do not mark entry as installed if install script failed
  * Fix showing updates when the option is selected (kde#416762)
  * Fix update auto selection (kde#419959)
  * Add KPackage support to KNewStuffCore (kde#418466)
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * KNewStuff: Fix file path and process call (kde#420312)
  * KNewStuff: port from KRun::runApplication to KIO::ApplicationLauncherJob
  * [KNewStuff] Port QRegExp to QRegularExpression
  * Replace Vokoscreen with VokoscreenNG (kde#416460)
  * Fix minor typo (stray word from the wrong bit of the sentence)
  * Fix minor typo
  * Introduce more user-visible error reporting for installations
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * Show filename too
  * Fix layout in DownloadItemsSheet (kde#419535)
  * [QtQuick dialog] Port to UrlBUtton and hide when there's no URL
  * Switch to using Kirigami's ShadowedRectangle
  * Fix update scenarios with no explicit downloadlink selected (kde#417510)
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Fix clicking thumb-only delegate (kde#418368)
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::. + they reverted error() -> networkError()
  * Fix scrolling on the EntryDetails page (kde#418191)
  * Don't double delete CommentsModel (kde#417802)
  * Make it compile against last qt5.15 without deprecated method. QProcess::execute(QString) is deprecated
  * Cover also the qtquick plugin in the installed categories file
  * Use ecm_qt_install_logging_categories over manual categories file
  * Use the right translation catalog to show translations
  * Fix the KNSQuick Dialog's close title and basic layout (kde#415606)
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Unbreak the KNSQuick::Engine::changedEntries functionality
  * Make it compile against last qt5.15 without deprecated methods
  * Add ellipsis at the end, as per HIG
  * API dox: add since for KDE_INSTALL_KNSRCDIR, note
    backward-compatible variant
  * Fix the KNSQuick Dialog's close title and basic layout
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Remove endl. qCritical/qDebug already adds a endl.
  * QHash::insertMulti is deprecated
  * Update the obsolete projects.kde.org URL
  * Ensure the dialog title is correct with an uninitialised engine
  * Don't show the info icon on the big preview delegate (kde#413436)
  * Support archive installs with adoption commands (kde#407687)
  * Send along the config name with requests
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Too many changes since 5.64.0, only listing bugfixes:
  * Fix i18n syntax to avoid runtime errors (kde#414498)
  * Correctly set i18n arguments in one pass (kde#414060)
  * Add OBS to screenrecorders (kde#412320)
  * Give some more pretty feedback in NewStuff::Page while the Engine is loading (kde#413439)
  * Add an overlay component for item activity feedback (kde#413441)
  * Only show DownloadItemsSheet if there's more than one download item (kde#413437)
  * Use the pointing hand cursor for the single-clickable delegates (kde#413435)
  * Fix the header layouts for EntryDetails and Page components (kde#413433)
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Ensure that the changedEntries property is correctly propagated
  * Fix KNSCore::Cache fetching when initialising Engine (kde#408716)
  * Use ECMGenerateExportHeader to manage deprecated API better
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Bring KNewStuffQuick to feature parity with KNewStuff(Widgets)
  * Remove dead icon loading code
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Remove unused includes
  * use local variable so it does not need ECM installed
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Use identical internet-services icon.
  * Port from KRun::runService to runApplication, so runService can be deprecated
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * [kmoretools] Add icons to download and install actions
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Fix build error in uploaddialog.ui
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Remove pixelated border (kde#391108)
  * Minor documentation clearup (missing support variable)
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Switch URLs to https
  * Update link to fsearch project
  * Set category on Attica entries
  * Handle unsupported OCS commands, and don't over-vote (kde#391111)
  * Remove some erroneously left-in debug, and leave one warning
  * New location for KNSRC files
  * [knewstuff] make it compile without foreach
  * [knewstuff] Remove qt5.13 deprecated method
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Port deprecated methods
  * Filter out invalid content in lists
  * Fix mem leak found by asan
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Delete copy constructor and assignment operator
  * delete copy constructor and assignment operator of some internal classes
  * Fix semantics for ghns_exclude (kde#402888)
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Remove old kde4 feature
  * Fix compile with strict compile flags
  * Use QStringLiteral + port to for(...:...)
  * Change default sort order in the download dialog to "Most downloads" (kde#399163)
  * Notify about the provider not being loaded
  * Forgot to include file
  * Export enum into qobject for easier debugging
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Remove unused include
  * Use new syntax
  * Mark new public bits as since 5.53
  * Add programmaticaly useful error signalling
  * It compiles without deprecated method
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Remove unused variable
  * Adapt autotest to new menu structure
  * More useful error messages
  * Use new connect syntax
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Use debug categories
  * Add support for Attica tags support
  * [KMoreTools] give the "Configure..." menu item an appropriate icon BUG: 398390 FIXED-IN: 5.51 (kde#398390)
  * [KMoreTools] Reduce menu hierarchy
  * Fix 'Impossible to use knsrc file for uploads from non standard location' (kde#397958)
  * Fix minor EBN issues
  * Remove an unneeded include (and fix a warning while we're at it)
  * Make test tools link on Windows
  * Unbreak build with Qt 5.9
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Cache providerId
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Remove long-time deprecated Encoding=UTF-8 from desktop format files
  * Change default sort order in the download dialog to Rating
  * Fix DownloadDialog window margins to meet general theme margins
  * Restore accidentally removed qCDebug
  * Use the right QSharedPointer API
  * Handle empty preview lists
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * [KMoreTools] Enable installing tools via appstream url
  * Remove KNS::Engine d-pointer hack
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * None
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Use override
  * Fix double margins around DownloadDialog
  * Fix hints in UI files about subclasses of custom widgets
  * Warning--
  * Don't offer qml plugin as a link target
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Make it public
  * Remove not necessary QtCore and co
  * Actually vote when clicking stars in the list view (kde#391112)
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Add explicit includes to fix build with Qt 5.11
  * Add vokoscreen to KMoreTools and add it to the "screenrecorder" grouping
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Limit request cache size
  * Require the same internal version as you're building
  * const'ify. Remove virtual when override is defined. Minor optimization
  * Prevent global variables from been using after freeing
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Fix some clazy warning
  * Revert "Detach before setting the d pointer" (kde#386156)
  * do not install development tool to aggregate desktop files
  * [knewstuff] Do not leak ImageLoader on error
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Remove PreferCache from network requests
  * Don't detach shared pointers to private data when setting previews.
  * Initialize pouinter
  * Check pointer before to use it
  * KMoreTools: Update and fix desktopfiles (kde#369646)
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Require Kirigami 2.1 instead of 1.0 for KNewStuffQuick
  * Properly create KPixmapSequence
  * Don't complain the knsregistry file is not present before it's useful
  * Detach before setting the d pointer
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * kmoretoolstest2 doesn't seem interactive, make it run as autotest
  * Adapt KMoreTools unittests so they can run without "make install".
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Give a parent to KMoreToolsMenuFactory menus
  * When requesting from the cache, report all entries at bulk
  * install categories file
  * Revert some part of eb2e65a882f0b95efeefe0115d9a942861768ba8
  * Allow to pass SearchRequest to QDebug
  * Add qCDebug
  * install categories file
  * Revert some part of eb2e65a882f0b95efeefe0115d9a942861768ba8
  * Document engine calls
* Wed Jul 12 2017 wbauer@tmo.at
- Move unversioned files to a new knewstuff package to be more
  compliant with the SLPP
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * install categories file
  * Revert some part of eb2e65a882f0b95efeefe0115d9a942861768ba8
  * Expand KNewStuff documentation
  * Fix incorrect error detection for missing knsrc files
  * Extend unittests to test stable sort.
  * Expose and use Engine's page size variable
  * Fix warnings
  * cmake: use ecm_add_test more
  * Use the right scope for the installpath variable
  * add .arcconfig file
  * Make it possible to use QXmlStreamReader to read a KNS registry file
  * [FEATURE] Option to build & install QCH files with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Use a single QNAM (and a disk cache) for HTTP jobs
  * Internal cache for provider data on initialisation
  * Improve some error messages
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Allow multiple categories with the same name
  * Improvements
  * Fix i18n puzzle again.
  * KNewStuff: Show file's size information in grid delegate.
  * i18n: fix string puzzle
  * If an entry's size is known, show it in the list view.
  * Register and declare KNSCore::EntryInternal::List as a metatype
  * Don't fall through the switch. Double entries? No please.
  * always close the downloaded file after downloading
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Fix compilation with Qt 5.6
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
* Fri Feb 17 2017 toddrme2178@gmail.com
- Add libKF5NewStuffCore5 to baselibs.conf
  libKF5NewStuff5-32bit cannot be installed without it.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Add new archive management option (subdir) to knsrc
  * Consume the new error signals (set job errors)
  * Handle oddity regarding files disappearing when just created
  * Actually install the core headers, with CamelCases
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Separate sort roles and filters
  * Make it possible to query installed entries
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Add KAuthorized checks to allow disabling of ghns in kdeglobals
    (kde#368240)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Uncompress archives in subfolders
  * No longer allow installing to generic data folder because
    of potential security hole
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Make sure we have a size to offer (kde#364896)
  * Fix "Download dialog fails when all categories missing"
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Don't initialize KNS3::DownloadManager with the wrong categories
  * Extend KNS3::Entry public API
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Do not crash if .desktop files are missing or broken
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Show a warning if there's an error in the Engine
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * registerServicesByGroupingNames can define default more items
  * Make KMoreToolsMenuFactory::createMenuFromGroupingNames lazy
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Fix 'KDE Partition Manager' desktop file and homepage URL
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Add new method fillMenuFromGroupingNames
  * KMoreTools: add many new groupings
  * KMoreToolsMenuFactory: handling for "git-clients-and-actions"
  * createMenuFromGroupingNames: make url parameter optional
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * New set of classes, called KMoreTools and related.
    KMoreTools helps to add hints about external tools which
    are potentially not yet installed. Furthermore, it makes long
    menus shorter by providing a main and more section which is
    also user-configurable.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
- Added kservice-devel (Build)Requires
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- Drop no longer needed Requires of the devel subpackage:
  karchive-devel and kio-devel
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Always reload xml data from remote urls
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Also allow absolute filepaths for configfile parameter.
  * Fix compilation on Windows
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * Many small fixes and cleanups
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * KNewStuff: installing "stuff" works again (porting bug)
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init knewstuff package
